Deleter

Struct Deleter 

pub struct Deleter { /* private fields */ }
Available on crate feature blocking only.
BlockingDeleter is designed to continuously remove content from storage.

It leverages batch deletion capabilities provided by storage services for efficient removal.

Implementations

Source

impl Deleter

pub fn delete(&mut self, input: impl IntoDeleteInput) -> Result<()>

Delete a path.

pub fn delete_iter<I, D>(&mut self, iter: I) -> Result<()>
where I: IntoIterator<Item = D>, D: IntoDeleteInput,

Delete an infallible iterator of paths.

Also see:

  • [BlockingDeleter::delete_try_iter]: delete an fallible iterator of paths.
pub fn delete_try_iter<I, D>(&mut self, try_iter: I) -> Result<()>
where I: IntoIterator<Item = Result<D>>, D: IntoDeleteInput,

Delete an fallible iterator of paths.

Also see:

  • [BlockingDeleter::delete_iter]: delete an infallible iterator of paths.
pub fn close(&mut self) -> Result<()>

Close the deleter, this will flush the deleter and wait until all paths are deleted.