BytesRange

Enum BytesRange 

pub enum BytesRange {
    Range {
        offset: u64,
        size: Option<u64>,
    },
    Suffix {
        size: u64,
    },
}
BytesRange carries a range of content.

BytesRange implements ToString which can be used as Range HTTP header directly.

<unit> should always be bytes.

Range: bytes=<range-start>-
Range: bytes=<range-start>-<range-end>
Range: bytes=-<suffix-length>

Variants



Range

Read from offset with optional size.

Fields

offset: u64

Offset of the range.

size: Option<u64>

Size of the range.



Suffix

Read the last size bytes.

Fields

size: u64

Size of the suffix range.

Implementations

Source

impl BytesRange

pub fn new(offset: u64, size: Option<u64>) -> Self

Create a new BytesRange

It better to use BytesRange::from(1024..2048) to construct.

Note

The behavior for None and Some of size is different.

  • size=None => bytes=<offset>-, read from <offset> until the end
  • size=Some(1024) => bytes=<offset>-<offset + 1024>, read 1024 bytes starting from the <offset>
pub fn suffix(size: u64) -> Self

Create a suffix BytesRange that reads the last size bytes.

pub fn offset(&self) -> u64

Get offset of BytesRange.

pub fn size(&self) -> Option<u64>

Get size of BytesRange.

pub fn is_suffix(&self) -> bool

Returns true if this range is a suffix range.

pub fn advance(&mut self, n: u64)

Advance the range by n bytes.

Panics

Panic if advancing the offset would overflow or if input n is larger than the size of the range.

pub fn is_full(&self) -> bool

Check if this range is full of this content.

If this range is full, we don’t need to specify it in http request.

pub fn to_header(&self) -> String

Convert bytes range into Range header.

Returns an empty string for a range with no valid HTTP representation – a zero size, or an end that overflows – which Display reports by failing. format! turns a Display failure into a panic, and this runs while a request is being built.

pub fn to_range(&self) -> impl RangeBounds<u64>

Convert bytes range into rust range.

pub fn to_range_as_usize(self) -> impl RangeBounds<usize>

Convert bytes range into rust range with usize.

pub fn to_content_range(self, content_length: usize) -> Result<Range<usize>>

Convert bytes range into a checked content slice range.