OpList

Struct OpList 

pub struct OpList { /* private fields */ }
Arguments for list operation.

Implementations

Source

impl OpList

pub fn new() -> Self

Create a new OpList.

pub fn with_limit(self, limit: usize) -> Self

Set the maximum number of results per request.

pub fn limit(&self) -> Option<usize>

Return the maximum number of results per request.

pub fn with_start_after(self, start_after: &str) -> Self

Set the key after which listing should start.

pub fn start_after(&self) -> Option<&str>

Return the key after which listing should start.

pub fn with_recursive(self, recursive: bool) -> Self

Set whether the list operation is recursive.

  • If false, the operation lists only the immediate children of the given path.
  • If true, the operation lists all entries whose paths start with the given path.

Defaults to false.

pub fn recursive(&self) -> bool

Return whether the list operation is recursive.

pub fn with_concurrent(self, concurrent: usize) -> Self

👎Deprecated since 0.53.2:

concurrent in list is no-op

Change the concurrent of this list operation.

The default concurrent is 1.

pub fn concurrent(&self) -> usize

👎Deprecated since 0.53.2:

concurrent in list is no-op

Get the concurrent of list operation.

pub fn with_versions(self, versions: bool) -> Self

Set whether to return object versions.

pub fn versions(&self) -> bool

Return whether the operation includes object versions.

pub fn with_deleted(self, deleted: bool) -> Self

Set whether to return deleted objects.

pub fn deleted(&self) -> bool

Return whether the operation includes deleted objects.