Executor

Struct Executor 

pub struct Executor { /* private fields */ }
Executor that runs futures in background.

Executor is created by users and used by opendal. So it’s by design that Executor only expose constructor methods.

Executor will run futures in background and return a Task as handle to the future. Users can call task.await to wait for the future to complete or drop the Task to cancel it.

Implementations

Source

impl Executor

pub fn new() -> Self

Create a default executor.

The default executor is enabled by feature flags. If no feature flags enabled, the default executor will always return error if users try to perform concurrent tasks.

pub fn with(exec: impl Execute) -> Self

Create a new executor with given execute impl.

pub fn into_inner(self) -> Arc<dyn Execute>

Return the inner executor.