FutureComposeSource

Struct FutureComposeSource 

pub struct FutureComposeSource<'a, F: Future<Output = Result<()>>> { /* private fields */ }
Composer::compose_with returns this future.

Use its methods to configure one source object before awaiting it.

Implementations

Source

impl<F: Future<Output = Result<()>>> FutureComposeSource<'_, F>

pub fn version(self, value: &str) -> Self

Compose this version of the source object.

pub fn if_match(self, value: &str) -> Self

Require this source ETag.

pub fn if_not_changed(self, metadata: &Metadata) -> Self

Require the source to retain the identity in metadata.