MetadataBuilder

Struct MetadataBuilder 

pub struct MetadataBuilder { /* private fields */ }
Mutable construction state for Metadata.

Implementations

Source

impl MetadataBuilder

pub fn file(content_length: u64) -> Self

Create a builder for file metadata with its complete content length.

pub fn dir() -> Self

Create a builder for directory metadata.

pub fn unknown() -> Self

Create a builder for metadata whose entry mode is not known.

pub fn set_file(&mut self, content_length: u64) -> &mut Self

Set the entry mode to file and replace its complete content length.

pub fn set_dir(&mut self) -> &mut Self

Set the entry mode to directory and discard any file content length.

pub fn set_unknown(&mut self) -> &mut Self

Set the entry mode to unknown and discard any file content length.

pub fn is_current(&mut self, value: Option<bool>) -> &mut Self

Set whether this metadata describes the current object version.

pub fn is_deleted(&mut self, value: bool) -> &mut Self

Set whether this metadata describes a deleted object.

pub fn cache_control(&mut self, value: impl Into<String>) -> &mut Self

Set the Cache-Control value.

pub fn content_md5(&mut self, value: impl Into<String>) -> &mut Self

Set the Content-MD5 value.

pub fn content_type(&mut self, value: impl Into<String>) -> &mut Self

Set the Content-Type value.

pub fn content_encoding(&mut self, value: impl Into<String>) -> &mut Self

Set the Content-Encoding value.

pub fn last_modified(&mut self, value: Timestamp) -> &mut Self

Set the last-modified timestamp.

pub fn etag(&mut self, value: impl Into<String>) -> &mut Self

Set the ETag.

pub fn content_disposition(&mut self, value: impl Into<String>) -> &mut Self

Set the Content-Disposition value.

pub fn version(&mut self, value: impl Into<String>) -> &mut Self

Set the object version.

pub fn user_metadata( &mut self, values: impl IntoIterator<Item = (String, String)>, ) -> &mut Self

Set user metadata from owned key-value pairs.

Duplicate keys are rejected because user metadata has map semantics.

Panics

Panics when values contains duplicate keys.

pub fn build(self) -> Metadata

Finish this builder as immutable metadata.

Panics

Panics when the compact value block, including its index, exceeds u16::MAX bytes.