pub struct OperatorInfo { /* private fields */ }Expand description
Metadata for operator, users can use this metadata to get information of operator.
Implementations
Sourceimpl OperatorInfo
impl OperatorInfo
Sourcepub fn name(&self) -> String
pub fn name(&self) -> String
Name of backend, could be empty if underlying backend doesn’t have namespace concept.
For example:
- name for
s3=> bucket name - name for
azblob=> container name
Sourcepub fn capability(&self) -> Capability
pub fn capability(&self) -> Capability
Get effective capability of operator.