pub struct RenameOptions {
pub if_not_exists: bool,
}Expand description
Options for rename operations.
Fields
if_not_exists: boolSets the condition that rename operation will succeed only if target does not exist.
Capability
Check crate::Capability::rename_with_if_not_exists before using this feature.
Behavior
- If the target does not exist, the rename operation succeeds.
- If the target exists, the operation returns
crate::ErrorKind::ConditionNotMatch. - If the service does not support this condition, the operation returns
crate::ErrorKind::Unsupported.