pub struct StatOptions {
pub version: Option<String>,
pub if_match: Option<String>,
pub if_none_match: Option<String>,
pub if_modified_since: Option<Timestamp>,
pub if_unmodified_since: Option<Timestamp>,
pub override_content_type: Option<String>,
pub override_cache_control: Option<String>,
pub override_content_disposition: Option<String>,
}Expand description
Options for stat operations.
Fields
version: Option<String>Set version for this operation.
This options can be used to retrieve the data of a specified version of the given path.
If the version doesn’t exist, an error with kind crate::ErrorKind::NotFound will be returned.
if_match: Option<String>Set if_match for this operation.
This option can be used to check if the file’s ETag matches the given ETag.
If file exists and it’s etag doesn’t match, an error with kind crate::ErrorKind::ConditionNotMatch
will be returned.
if_none_match: Option<String>Set if_none_match for this operation.
This option can be used to check if the file’s ETag doesn’t match the given ETag.
If file exists and it’s etag match, an error with kind crate::ErrorKind::ConditionNotMatch
will be returned.
if_modified_since: Option<Timestamp>Set if_modified_since for this operation.
This option can be used to check if the file has been modified since the given timestamp.
If file exists and it hasn’t been modified since the specified time, an error with kind
crate::ErrorKind::ConditionNotMatch will be returned.
if_unmodified_since: Option<Timestamp>Set if_unmodified_since for this operation.
This feature can be used to check if the file hasn’t been modified since the given timestamp.
If file exists and it has been modified since the specified time, an error with kind
crate::ErrorKind::ConditionNotMatch will be returned.
override_content_type: Option<String>Specify the content-type header that should be sent back by the operation.
This option is only meaningful when used along with presign.
override_cache_control: Option<String>Specify the cache-control header that should be sent back by the operation.
This option is only meaningful when used along with presign.
override_content_disposition: Option<String>Specify the content-disposition header that should be sent back by the operation.
This option is only meaningful when used along with presign.