pub struct OpList { /* private fields */ }Expand description
Arguments for list operation.
Implementations
Sourceimpl OpList
impl OpList
Sourcepub fn with_limit(self, limit: usize) -> Self
pub fn with_limit(self, limit: usize) -> Self
Set the maximum number of results per request.
Sourcepub fn with_start_after(self, start_after: &str) -> Self
pub fn with_start_after(self, start_after: &str) -> Self
Set the key after which listing should start.
Sourcepub fn start_after(&self) -> Option<&str>
pub fn start_after(&self) -> Option<&str>
Return the key after which listing should start.
Sourcepub fn with_recursive(self, recursive: bool) -> Self
pub fn with_recursive(self, recursive: bool) -> Self
Set whether the list operation is recursive.
- If
false, the operation lists only the immediate children of the given path. - If
true, the operation lists all entries whose paths start with the given path.
Defaults to false.
Sourcepub fn with_concurrent(self, concurrent: usize) -> Self
👎Deprecated since 0.53.2: concurrent in list is no-op
pub fn with_concurrent(self, concurrent: usize) -> Self
concurrent in list is no-op
Change the concurrent of this list operation.
The default concurrent is 1.
Sourcepub fn concurrent(&self) -> usize
👎Deprecated since 0.53.2: concurrent in list is no-op
pub fn concurrent(&self) -> usize
concurrent in list is no-op
Get the concurrent of list operation.
Sourcepub fn with_versions(self, versions: bool) -> Self
pub fn with_versions(self, versions: bool) -> Self
Set whether to return object versions.
Sourcepub fn with_deleted(self, deleted: bool) -> Self
pub fn with_deleted(self, deleted: bool) -> Self
Set whether to return deleted objects.